..
   # Copyright (c) 2023 Graphcore Ltd. All rights reserved.
   # Copyright (c) 2007-2023 by the Sphinx team. All rights reserved.

{{ fullname | escape | underline}}

.. currentmodule:: {{ module }}

.. autoclass:: {{ objname }}
   :members:
   :inherited-members: Module
   :exclude-members: extra_repr, forward
